==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/creatures/dialogs_pl.lua <==

dialogId("kor-m-podivej", "font_small", "Look at all these lobsters...")
dialogStr("Spójrz na te wszystkie kraby...")


dialogId("kor-v-spitu", "font_big", "They sleep for thousands of years... in eternal stillness...")
dialogStr("Śpią tu od tysiącleci, zastygłe na wieczność...")


dialogId("kor-m-avlada", "font_small", "...and the government tries to cover it up.")
dialogStr("...a rząd próbuje to zatuszować.")


dialogId("kor-v-nicje", "font_big", "...nothing can wake them up...")
dialogStr("...nic ich nie może obudzić...")


dialogId("kor-m-pokud", "font_small", "Unless we activate that octopus.")
dialogStr("Póki nie szturchniemy tej ośmiornicy.")


dialogId("kor-v-podivej", "font_big", "Look, everything here is so still and quiet.")
dialogStr("Zobacz, jaka tu cisza i spokój.")


dialogId("kor-m-vzdyt", "font_small", "But the anemones are moving.")
dialogStr("Ukwiały się ruszają.")


dialogId("kor-v-treba", "font_big", "Maybe they`re in the throes of death.")
dialogStr("Może to agonalne drgawki.")


dialogId("kor-v-shledavam", "font_big", "I find a certain symbolism in that.")
dialogStr("Wydaje mi się to bardzo symboliczne.")


dialogId("kor-v-bermudy", "font_big", "That`s interesting. This type of coral normally grows only in the Bermuda Triangle.")
dialogStr("Interesujące, ten gatunek korali normalnie występuje tylko w Trójkącie Bermudzkim.")


dialogId("kor-v-inteligentni", "font_big", "Did you know that some types of coral are almost as intelligent as fish?")
dialogStr("Wiesz, że niektóre korale są prawie tak inteligentne jak ryby?")


dialogId("kor-v-jedovate", "font_big", "Be careful, most types of coral are poisonous.")
dialogStr("Uważaj, większość korali jest trująca.")


dialogId("kor-m-dusi", "font_small", "What do you think, is there such a thing as a 'coral-soul`?")
dialogStr("Myślisz, że korale mają duszę?")


dialogId("kor-m-pocit", "font_small", "Do you have the feeling that those coral are watching us?")
dialogStr("Nie wydaje ci się, że te korale nas obserwują?")


dialogId("kor-m-bizarni", "font_small", "I wonder why the coral have such a bizarre shape.")
dialogStr("Zastanawiam się, czemu te korale mają taki dziwny kształt.")


dialogId("kor-v-juchacka", "font_big", "That was some number, wasn`t it?")
dialogStr("Niezłe to było, nie?")


dialogId("kor-m-hraje", "font_small", "Yeah, he`s a great player.")
dialogStr("No, całkiem przyzwoity z niego muzykant.")


dialogId("kor-v-odvaz", "font_big", "That`s cool. What if we pushed him again?")
dialogStr("Super! Może go jeszcze raz popchniemy?")


dialogId("kor-m-vsimlsis", "font_small", "Did you see what the lobsters were doing?")
dialogStr("Widziałeś, co robiły kraby?")


dialogId("kor-v-avidelas", "font_big", "And how those anemones were dancing?")
dialogStr("A widziałaś, jak te ukwiały tańczyły?")


dialogId("kor-m-tovis", "font_small", "Well, you know, it`s not all that much fun down here at the bottom of the ocean.")
dialogStr("Wiesz, na dnie oceanu trudno o chwilę dobrej zabawy.")


dialogId("kor-v-vali", "font_big", "He`s good, isn`t he?")
dialogStr("Dobry jest.")


dialogId("kor-m-nachob", "font_small", "Not bad for an octopus...")
dialogStr("Całkiem niezły, jak na ośmiornicę...")


dialogId("kor-m-jinou", "font_small", "Do you think he knows any other tune?")
dialogStr("Myślisz, że zna jakąś inną melodię?")


dialogId("kor-m-neprehani", "font_small", "Don`t you think we`ve had enough already?")
dialogStr("Nie uważasz, że już tego wystarczy?")


dialogId("kor-m-lezekrkem", "font_small", "I`m getting sick of it...")
dialogStr("Już mi się to znudziło...")


dialogId("kor-v-lezekrkem", "font_big", "I`m sick and tired of it...")
dialogStr("Już mi to skrzelami wychodzi...")


dialogId("kor-v-kostice", "font_big", "I`m fed up to the gills with this.")
dialogStr("Mam tego po dziurki w... yyy...")


dialogId("kor-v-odsud", "font_big", "I can`t budge this from where I am. I`d have to try to move it from the left side.")
dialogStr("Nie mogę tego stąd popchnąć. Musiałbym spróbować od lewej.")


dialogId("kor-m-budesmuset", "font_small", "Well you`ll have to go that way through those anemones.")
dialogStr("No to będziesz musiał jakoś przebrnąć przez te ukwiały.")


dialogId("kor-m-neniono", "font_small", "That`s not what I had in mind...")
dialogStr("Nie to chciałam zrobić...")


dialogId("kor-m-tudiru", "font_small", "We should have plugged that hole beforehand.")
dialogStr("Powinniśmy byli zawczasu tę dziurę zatkać.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/creatures/dialogs_pl.lua <==

dialogId("kor-m-podivej", "font_small", "Look at all these lobsters...")
dialogStr("Spójrz na te wszystkie kraby...")


dialogId("kor-v-spitu", "font_big", "They sleep for thousands of years... in eternal stillness...")
dialogStr("Śpią tu od tysiącleci, zastygłe na wieczność...")


dialogId("kor-m-avlada", "font_small", "...and the government tries to cover it up.")
dialogStr("...a rząd próbuje to zatuszować.")


dialogId("kor-v-nicje", "font_big", "...nothing can wake them up...")
dialogStr("...nic ich nie może obudzić...")


dialogId("kor-m-pokud", "font_small", "Unless we activate that octopus.")
dialogStr("Póki nie szturchniemy tej ośmiornicy.")


dialogId("kor-v-podivej", "font_big", "Look, everything here is so still and quiet.")
dialogStr("Zobacz, jaka tu cisza i spokój.")


dialogId("kor-m-vzdyt", "font_small", "But the anemones are moving.")
dialogStr("Ukwiały się ruszają.")


dialogId("kor-v-treba", "font_big", "Maybe they’re in the throes of death.")
dialogStr("Może to agonalne drgawki.")


dialogId("kor-v-shledavam", "font_big", "I find a certain symbolism in that.")
dialogStr("Wydaje mi się to bardzo symboliczne.")


dialogId("kor-v-bermudy", "font_big", "That’s interesting. This type of coral normally grows only in the Bermuda Triangle.")
dialogStr("Interesujące, ten gatunek korali normalnie występuje tylko w Trójkącie Bermudzkim.")


dialogId("kor-v-inteligentni", "font_big", "Did you know that some types of coral are almost as intelligent as fish?")
dialogStr("Wiesz, że niektóre korale są prawie tak inteligentne jak ryby?")


dialogId("kor-v-jedovate", "font_big", "Be careful, most types of coral are poisonous.")
dialogStr("Uważaj, większość korali jest trująca.")


dialogId("kor-m-dusi", "font_small", "What do you think, is there such a thing as a 'coral-soul’?")
dialogStr("Myślisz, że korale mają duszę?")


dialogId("kor-m-pocit", "font_small", "Do you have the feeling that those coral are watching us?")
dialogStr("Nie wydaje ci się, że te korale nas obserwują?")


dialogId("kor-m-bizarni", "font_small", "I wonder why the coral have such a bizarre shape.")
dialogStr("Zastanawiam się, czemu te korale mają taki dziwny kształt.")


dialogId("kor-v-juchacka", "font_big", "That was some number, wasn’t it?")
dialogStr("Niezłe to było, nie?")


dialogId("kor-m-hraje", "font_small", "Yeah, he’s a great player.")
dialogStr("No, całkiem przyzwoity z niego muzykant.")


dialogId("kor-v-odvaz", "font_big", "That’s cool. What if we pushed him again?")
dialogStr("Super! Może go jeszcze raz popchniemy?")


dialogId("kor-m-vsimlsis", "font_small", "Did you see what the lobsters were doing?")
dialogStr("Widziałeś, co robiły kraby?")


dialogId("kor-v-avidelas", "font_big", "And how those anemones were dancing?")
dialogStr("A widziałaś, jak te ukwiały tańczyły?")


dialogId("kor-m-tovis", "font_small", "Well, you know, it’s not all that much fun down here at the bottom of the ocean.")
dialogStr("Wiesz, na dnie oceanu trudno o chwilę dobrej zabawy.")


dialogId("kor-v-vali", "font_big", "He’s good, isn’t he?")
dialogStr("Dobry jest.")


dialogId("kor-m-nachob", "font_small", "Not bad for an octopus...")
dialogStr("Całkiem niezły, jak na ośmiornicę...")


dialogId("kor-m-jinou", "font_small", "Do you think he knows any other tune?")
dialogStr("Myślisz, że zna jakąś inną melodię?")


dialogId("kor-m-neprehani", "font_small", "Don’t you think we’ve had enough already?")
dialogStr("Nie uważasz, że już tego wystarczy?")


dialogId("kor-m-lezekrkem", "font_small", "I’m getting sick of it...")
dialogStr("Już mi się to znudziło...")


dialogId("kor-v-lezekrkem", "font_big", "I’m sick and tired of it...")
dialogStr("Już mi to skrzelami wychodzi...")


dialogId("kor-v-kostice", "font_big", "I’m fed up to the gills with this.")
dialogStr("Mam tego po dziurki w... yyy...")


dialogId("kor-v-odsud", "font_big", "I can’t budge this from where I am. I’d have to try to move it from the left side.")
dialogStr("Nie mogę tego stąd popchnąć. Musiałbym spróbować od lewej.")


dialogId("kor-m-budesmuset", "font_small", "Well you’ll have to go that way through those anemones.")
dialogStr("No to będziesz musiał jakoś przebrnąć przez te ukwiały.")


dialogId("kor-m-neniono", "font_small", "That’s not what I had in mind...")
dialogStr("Nie to chciałam zrobić...")


dialogId("kor-m-tudiru", "font_small", "We should have plugged that hole beforehand.")
dialogStr("Powinniśmy byli zawczasu tę dziurę zatkać.")
